import { Component, h, Prop, Event, Watch, State } from '@stencil/core';
//import { CheckboxState } from './types'
export class Checkbox {
  constructor() {
    /**
     * The visual label for the checkbox
     */
    this.label = 'Checkbox Label';
    /**
     * Whether the checkbox is selected
     */
    this.checked = false;
    /**
     * Remove all interactivity from the checkbox
     */
    this.disabled = false;
    /**
     * If the value is required or optional
     */
    this.required = false;
    this.handleStateChange = (event) => {
      const checkbox = event.target;
      // Update our internal state 
      this.internalChecked = checkbox.checked;
    };
  }
  componentWillLoad() {
    this.internalChecked = this.checked;
  }
  checkedPropChanged(newValue, _) {
    this.internalChecked = newValue;
  }
  render() {
    return (h("div", { class: "group flex flex-row items-center" },
      h("input", { type: 'checkbox', id: `control-${this.name}`, name: this.name, value: this.value, disabled: this.disabled, checked: this.checked, class: getCheckboxClasses(), onChange: this.handleStateChange }),
      this.internalChecked == true && (h("div", { "aria-hidden": 'true', class: `absolute flex items-center justify-center h-5 w-5` },
        h("cosmos-icon", { name: 'check', size: 's', color: 'text-palette-white' }))),
      h("cosmos-form-label", { required: this.required, disabled: this.disabled, text: this.label, for: this.disabled ? null : `control-${this.name}` })));
  }
  static get is() { return "cosmos-checkbox"; }
  static get properties() { return {
    "name": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": true,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The unique name of the checkbox"
      },
      "attribute": "name",
      "reflect": false
    },
    "label": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The visual label for the checkbox"
      },
      "attribute": "label",
      "reflect": false,
      "defaultValue": "'Checkbox Label'"
    },
    "checked": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Whether the checkbox is selected"
      },
      "attribute": "checked",
      "reflect": false,
      "defaultValue": "false"
    },
    "disabled": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Remove all interactivity from the checkbox"
      },
      "attribute": "disabled",
      "reflect": true,
      "defaultValue": "false"
    },
    "required": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "If the value is required or optional"
      },
      "attribute": "required",
      "reflect": false,
      "defaultValue": "false"
    },
    "value": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The value of the checkbox"
      },
      "attribute": "value",
      "reflect": false
    }
  }; }
  static get states() { return {
    "internalChecked": {}
  }; }
  static get events() { return [{
      "method": "change",
      "name": "change",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "An event is emitted with the new `CheckboxState`"
      },
      "complexType": {
        "original": "MouseEvent",
        "resolved": "MouseEvent",
        "references": {
          "MouseEvent": {
            "location": "global"
          }
        }
      }
    }]; }
  static get watchers() { return [{
      "propName": "checked",
      "methodName": "checkedPropChanged"
    }]; }
}
function getCheckboxClasses() {
  return [
    'appearance-none',
    'rounded',
    'border',
    'border-palette-neutral-5',
    "w-5",
    "h-5",
    'mr-3',
    'disabled:border-0',
    'disabled:bg-interactive-disabled',
    'group-hover:border-interactive-hover',
    'focus:border-interactive-hover',
    //'focus:rounded-none',
    'focus:outline',
    'focus:shadow-1',
    'checked:border-interactive-selected',
    'checked:bg-interactive-selected',
    'focus:checked:border-interactive-selected',
    'group-hover:checked:border-interactive-selected',
  ].join(' ');
}
//function getStylesForState(state: CheckboxState): Array<string> {
//    if (['checked'].includes(state)) {
//        return [
//            'border-interactive-selected',
//            'bg-interactive-selected',
//        ]
//    }
//
//    return [
//        'border-palette-neutral-5'
//    ]
//}
